@@ -29,6 +29,7 @@ class AMQPData(GeneralData):
         self.ping = kwargs.get('ping', 30)
         self.multi = kwargs.get('multiprocessing', False)
         self.ttl = kwargs.get('ttl',1200000)
+        self.source = kwargs.get('source',False)
         try:
             self.connect()
         except Exception as e:
@@ -61,15 +62,16 @@ class AMQPData(GeneralData):
             self.channel = self.connection.channel()
             # bind by default to:
             # conecta exchange con queue
-            self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
             self.connected = True
         except Exception as e:
             self.logger.exception("Error conectando canal Rabbitmq")
             raise e
         try:
-            self.channel.queue_declare(self.queue_name, 
-                durable=self.durable, 
-                arguments={'x-message-ttl' : self.ttl})
+            if self.source:
+                self.channel.queue_declare(self.queue_name, 
+                    durable=self.durable, 
+                    arguments={'x-message-ttl' : self.ttl})
+                self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
         except Exception as e:
             self.logger.exception("Error declaring queue -> %s" % e)
             self.connected = False
